pub struct Executor { /* private fields */ }Expand description
Executes a sequence of systems, potentially in parallel, and then commits their command buffers.
Systems are provided in execution order. When the par-schedule feature is enabled, the Executor
may run some systems in parallel. The order in which side-effects (e.g. writes to resources
or entities) are observed is maintained.
Implementations
Sourceimpl Executor
impl Executor
Sourcepub fn new(systems: Vec<Box<dyn Schedulable>>) -> Self
pub fn new(systems: Vec<Box<dyn Schedulable>>) -> Self
Constructs a new executor for all systems to be run in a single stage.
Systems are provided in the order in which side-effects (e.g. writes to resources or entities) are to be observed.
Sourcepub fn into_vec(self) -> Vec<Box<dyn Schedulable>>
pub fn into_vec(self) -> Vec<Box<dyn Schedulable>>
Converts this executor into a vector of its component systems.
Sourcepub fn execute(&mut self, world: &mut World, resources: &mut Resources)
pub fn execute(&mut self, world: &mut World, resources: &mut Resources)
Executes all systems and then flushes their command buffers.
Sourcepub fn run_systems(&mut self, world: &mut World, resources: &mut Resources)
pub fn run_systems(&mut self, world: &mut World, resources: &mut Resources)
Executes all systems sequentially.
Only enabled with par-schedule is disabled
Sourcepub fn flush_command_buffers(&mut self, world: &mut World)
pub fn flush_command_buffers(&mut self, world: &mut World)
Flushes the recorded command buffers for all systems.